@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2024 the Eask authors.
+ * Copyright (C) 2022-2025 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['dist [destination]', 'distribution [destination]'];
-exports.desc = 'Delete dist subdirectory';
+exports.desc = 'Delete the dist directory where the build output is stored';
 exports.builder = yargs => yargs
   .positional(
     'destination', {
